@@ -2,6 +2,22 @@ from syned.beamline.shape import SurfaceShape
 from syned.beamline.optical_element_with_surface_shape import OpticalElementsWithSurfaceShape
 
 class Mirror(OpticalElementsWithSurfaceShape):
+    """
+    Constructor.
+
+    Parameters
+    ----------
+    name : str
+        The name of the optical element.
+    surface_shape : instance of SurfaceShape, optional
+        The geometry of the crystal surface. if None, it is initialized to SurfaceShape().
+    boundary_shape : instance of BoundaryShape, optional
+        The geometry of the slit aperture. if None, it is initialized to BoundaryShape().
+    coating : str, optional
+        The grating coating material.
+    coating_thickness : float, optional
+        The grating coating thickness in m.
+    """
     def __init__(self,
                  name="Undefined",
                  surface_shape=SurfaceShape(),
